@@ -93,20 +93,6 @@ typedef struct response {
 } *HttpResponse;
 
 
-struct  ServiceImpl {
-        void(*doGet)(HttpRequest, HttpResponse);
-        void(*doPost)(HttpRequest, HttpResponse);
-};
-
-
-/*
- * An object for implementors of the service functions; doGet and
- * doPost. Implementing modules i.e. CERVLETS, must implement the
- * doGet and doPost functions and the engine will call the add_Impl
- * function to setup the callback to these functions.
- */
-struct ServiceImpl Impl;
-
 /* Public prototypes */
 void *http_processor(Socket_T);
 char *get_headers(HttpResponse res);
