@@ -256,7 +256,9 @@ typedef enum {
         Resource_MemoryKbyteTotal,
         Resource_MemoryPercentTotal,
         Resource_Inode,
+        Resource_InodeFree,
         Resource_Space,
+        Resource_SpaceFree,
         Resource_CpuUser,
         Resource_CpuSystem,
         Resource_CpuWait,
