@@ -58,6 +58,9 @@
 #include "process.h"
 #include "process_sysdep.h"
 
+// libmonit
+#include "system/Time.h"
+
 /**
  *  General purpose /proc methods.
  *
@@ -70,14 +73,14 @@
 
 /**
  * Initialize the proc information code
- * @return TRUE if succeeded otherwise FALSE.
+ * @return true if succeeded otherwise false.
  */
-int init_process_info(void) {
+boolean_t init_process_info(void) {
         memset(&systeminfo, 0, sizeof(SystemInfo_T));
         gettimeofday(&systeminfo.collected, NULL);
-        if(uname(&systeminfo.uname) < 0) {
+        if (uname(&systeminfo.uname) < 0) {
                 LogError("'%s' resource monitoring initialization error -- uname failed: %s\n", Run.system->name, STRERROR);
-                return FALSE;
+                return false;
         }
 
         systeminfo.total_cpu_user_percent = -10;
@@ -93,9 +96,9 @@ int init_process_info(void) {
  * status), enduser version.
  * @param p A Service object
  * @param pid The process id
- * @return TRUE if succeeded otherwise FALSE.
+ * @return true if succeeded otherwise false.
  */
-int update_process_data(Service_T s, ProcessTree_T *pt, int treesize, pid_t pid) {
+boolean_t update_process_data(Service_T s, ProcessTree_T *pt, int treesize, pid_t pid) {
         ASSERT(s);
         ASSERT(systeminfo.mem_kbyte_max > 0);
 
@@ -111,10 +114,10 @@ int update_process_data(Service_T s, ProcessTree_T *pt, int treesize, pid_t pid)
                 s->inf->priv.process.uid               = pt[leaf].uid;
                 s->inf->priv.process.euid              = pt[leaf].euid;
                 s->inf->priv.process.gid               = pt[leaf].gid;
-                s->inf->priv.process.uptime            = time(NULL) - pt[leaf].starttime;
+                s->inf->priv.process.uptime            = Time_now() - pt[leaf].starttime;
                 s->inf->priv.process.children          = pt[leaf].children_sum;
                 s->inf->priv.process.mem_kbyte         = pt[leaf].mem_kbyte;
-                s->inf->priv.process.status_flag       = pt[leaf].status_flag;
+                s->inf->priv.process.zombie            = pt[leaf].zombie;
                 s->inf->priv.process.total_mem_kbyte   = pt[leaf].mem_kbyte_sum;
                 s->inf->priv.process.cpu_percent       = pt[leaf].cpu_percent;
                 s->inf->priv.process.total_cpu_percent = pt[leaf].cpu_percent_sum;
@@ -139,20 +142,20 @@ int update_process_data(Service_T s, ProcessTree_T *pt, int treesize, pid_t pid)
                 s->inf->priv.process.cpu_percent       = 0;
                 s->inf->priv.process.total_cpu_percent = 0;
         }
-        return TRUE;
+        return true;
 }
 
 
 /**
  * Updates the system wide statistic
- * @return TRUE if successful, otherwise FALSE
+ * @return true if successful, otherwise false
  */
-int update_system_load() {
+boolean_t update_system_load() {
         if (Run.doprocess) {
                 ASSERT(systeminfo.mem_kbyte_max > 0);
 
                 /** Get load average triplet */
-                if (-1 == getloadavg_sysdep(systeminfo.loadavg, 3)) {
+                if (getloadavg_sysdep(systeminfo.loadavg, 3) == -1) {
                         LogError("'%s' statistic error -- load average gathering failed\n", Run.system->name);
                         goto error1;
                 }
@@ -171,7 +174,7 @@ int update_system_load() {
                         goto error3;
                 }
 
-                return TRUE;
+                return true;
         }
 
 error1:
@@ -186,7 +189,7 @@ error3:
         systeminfo.total_cpu_syst_percent = 0;
         systeminfo.total_cpu_wait_percent = 0;
 
-        return FALSE;
+        return false;
 }
 
 
@@ -211,13 +214,13 @@ int initprocesstree(ProcessTree_T **pt_r, int *size_r, ProcessTree_T **oldpt_r,
 
         if ((*size_r = initprocesstree_sysdep(pt_r)) <= 0 || ! *pt_r) {
                 DEBUG("System statistic error -- cannot initialize the process tree -- process resource monitoring disabled\n");
-                Run.doprocess = FALSE;
+                Run.doprocess = false;
                 if (*oldpt_r)
                         delprocesstree(oldpt_r, oldsize_r);
                 return -1;
-        } else if (Run.doprocess == FALSE) {
+        } else if (! Run.doprocess) {
                 DEBUG("System statistic -- initialization of the process tree succeeded -- process resource monitoring enabled\n");
-                Run.doprocess = TRUE;
+                Run.doprocess = true;
         }
 
         int oldentry;
@@ -295,19 +298,30 @@ int initprocesstree(ProcessTree_T **pt_r, int *size_r, ProcessTree_T **oldpt_r,
  * @param treesize  size of the processtree
  * @return process index if succeeded otherwise -1
  */
-int findprocess(int pid, ProcessTree_T *pt, int size) {
+int findprocess(int pid, ProcessTree_T *pt, int treesize) {
         ASSERT(pt);
 
-        if (size <= 0)
+        if (treesize <= 0)
                 return -1;
 
-        for (int i = 0; i < size; i++)
+        for (int i = 0; i < treesize; i++)
                 if (pid == pt[i].pid)
                         return i;
 
         return -1;
 }
 
+
+time_t getProcessUptime(pid_t pid, ProcessTree_T *pt, int treesize) {
+        if (pt) {
+                int leaf = findprocess(pid, pt, treesize);
+                return (time_t)((leaf >= 0 && leaf < treesize) ? Time_now() - pt[leaf].starttime : -1);
+        } else {
+                return 0;
+        }
+}
+
+
 /**
  * Delete the process tree
  */
@@ -346,12 +360,12 @@ void process_testmatch(char *pattern) {
                 printf("List of processes matching pattern \"%s\":\n", pattern);
                 printf("------------------------------------------\n");
                 for (int i = 0; i < ptreesize; i++) {
-                        int match = FALSE;
+                        boolean_t match = false;
                         if (ptree[i].cmdline && ! strstr(ptree[i].cmdline, "procmatch")) {
 #ifdef HAVE_REGEX_H
-                                match = regexec(regex_comp, ptree[i].cmdline, 0, NULL, 0) ? FALSE : TRUE;
+                                match = regexec(regex_comp, ptree[i].cmdline, 0, NULL, 0) ? false : true;
 #else
-                                match = strstr(ptree[i].cmdline, pattern) ? TRUE : FALSE;
+                                match = strstr(ptree[i].cmdline, pattern) ? true : false;
 #endif
                                 if (match) {
                                         printf("\t%s\n", ptree[i].cmdline);
